# Please go to the end to see rules of defining an atom  

============================================================================================
                        Definition begin
============================================================================================
--------------------------------------------------------------------------------------------
WILDATOM XX C N O S P
WILDATOM XA O S
WILDATOM XB C3 N2 N3 O2 S2 P2
WILDATOM XD S P
-------------------------------------------------------------------------------------------- 
 f1  f2    f3  f4  f5  f6  f7  f8      		f9          
-------------------------------------------------------------------------------------------- 
//3-membered ring atom
ATD  11    *   6   4  &
ATD  15    *   6   2  &
ATD  15    *   6   1  &
ATD  17    *   6   3  *  *  [AR1.AR2]         (O2[AR1.AR2]) & 
ATD  17    *   6   3  *  *  [AR1.AR2] 	      (N2[AR1.AR2]) &
ATD  16    *   6   3  *  *  [AR1.AR2]         &
ATD  14    *   6   3  *  *  *                     (XA1) &   
ATD  14    *   6   3  *  *  *                     (XA1,XA1) &   
ATD  13    *   6   3  *  *  *			  (N2[db']) &   
ATD  13    *   6   3  *  *  *                     (N3[db']) &   
ATD  13    *   6   3  *  *  *			  (N4[db']) &   
ATD  13    *   6   3  *  *  *			  (P2[db']) &   
ATD  13    *   6   3  *  *  *			  (P3[db']) &   
ATD  13    *   6   3  *  *  *			  (P4[db']) &   
ATD  12    *   6   3  &    
ATD  11    *   6   &    
//end of carbon
ATD  91    *   1   &
ATD  61    *   14  & 
ATD  71    *   9   &
ATD  72    *   17  &
ATD  73    *   35  &      
ATD  74    *   53  &      
//
ATD  42    *   15  4  &  
ATD  41    *   15  2  &  
ATD  41    *   15  1  &  
ATD  42    *   15  3  *   * [db]                  &  
ATD  41    *   15  3  &  
ATD  41    *   15  &  
//end of phosphorus
ATD  33    *   8   1  *  *  *     		  (C3[RG](O2)) &
ATD  33    *   8   1  *  *  *     		  (C3[RG](N3)) &
ATD  32    *   8   1  *  *  *     		  (C3(O2)) &
ATD  31    *   8   1  &
ATD  31    *   8   2  &
ATD  31    *   8   &
//end of oxygen
ATD  21    *   7   4  &  
ATD  25    *   7   1  &
ATD  23    *   7   3  *  *  [AR1.AR2]  		  & 
ATD  22    *   7   3  *  *  *  			  (C3(O1)) & 
ATD  22    *   7   3  *  *  *  			  (C3(S1)) & 
ATD  23    *   7   3  *  *  *  			  (O1,O1) &
ATD  23    *   7   3  *  *  *          		  (C3(N3[db])) & 
ATD  23    *   7   3  *  *  *          		  (N2(N3[db])) & 
ATD  23    *   7   3  *  *  *          		  (P2(N3[db])) & 
ATD  23    *   7   3  *  *  *          		  (XX[AR1.AR2]<a1>,XB(XB(XX[AR1.AR2]<a2>))) a1:a2:any 
ATD  23    *   7   3  *  *  *          		  (XB(XX[AR1.AR2]<a1>),XB(XX[AR1.AR2]<a2>)) a1:a2:any 
ATD  23    *   7   3  *  *  [db]   		  & 
ATD  21    *   7   3  &
ATD  22    *   7   2  *  *  [2sb]  		  (C3(O1)) &
ATD  22    *   7   2  *  *  [2sb]  		  (C3(S1)) & 
ATD  21    *   7   2  *  *  [2sb]   		  &
ATD  24    *   7   2  *  *  [sb,db]   		  &
ATD  24    *   7   2   *   *   [RG5]             (N2[RG5](N2[RG5](N2[RG5])))    &
ATD  24    *   7   2   *   *   [RG5]             (N2[RG5],N2[RG5](N2[RG5]))     &
ATD  25    *   7   2  &
ATD  25    *   7   &
//end of nitrogen
ATD  51    *   16  1  & 
ATD  51    *   16  2  &
ATD  52    *   16  3  & 
ATD  53    *   16  4  & 
ATD  DU  &   
============================================================================================
			Field descriptions
============================================================================================
f1  ATD, which stands for atom type definition, ATD should always in the first three columns 
f2  Atom type name, can be letters or numbers   
f3  Residue names, which means this description is only applied to atoms in special residues
f4  Atomic number 
f5  Number of attached atoms 
f6  Number of attached hydrogen atoms
f7  For hydrogen, number of the electron-withdrawal atoms connected to the atom that the 
    hydrogen attached
f8  Atomic property
f9  Chemical environment definitions


============================================================================================
			Specific symbols
============================================================================================
*  Ignore this field
&  End of definition 
.  "or" operation in the ring and aromatity descriptions 


============================================================================================
			Predefined words
============================================================================================
EW   Electron-withdraw atom
AA   Amino acid residue
NA   Nucleic acid
BIO  AA + NA

AR1  Pure aromatic atom (such as benzene and pyridine)
AR2  Atom in a planar ring, usually the ring has two continuous single bonds and at least two 
     double bonds
AR3  Atom in a planar ring, which has one or several double bonds formed between non-ring atoms
     and the ring atoms
AR4  Atom other than AR1, AR2, AR3 and AR5. 
AR5  Pure aliphatic atom in a ring, which is made of sp3 carbon

RG   Ring (from 3-membered to nine-membered)
RG3  3-membered ring 
RG4  4-membered ring 
RG5  5-membered ring 
RG6  6-membered ring 
RG7  7-membered ring 
RG8  8-membered ring 
RG9  9-membered ring 
NR   Non-ring atom

SB   Single bond
DB   Double bond
TB   Triple bond
AB   Aromatic bond
DL   Delocalized bond (9 in AM1-BCC)
sb   Single bond, including aromatic single, delocalized bond (9 in AM1-BCC) 
db   Double bond, including aromatic double
tb   Triple bond
 
'    Bond type (SB sb etc) followed by ' means the current atom forms this kind of bond with the 
     immediate predecessor in a chain of atoms
     For example, (XD3[SB',db]) means the current atom XD3 has a double bond with the atom in 
     definition 
''   Bond type (SB sb etc) followed by '' means the current atom does not form this kind of bond 
     with the immediate predecessor in a chain of atoms
============================================================================================
			Miscellaneous
============================================================================================
1. Maximum line length is MAXCHAR (defined in define.h) characters
2. No space in the atomic property string
3. No space in the chemical environment string 
4. No filed missing before &
5. The definition order is crucial, special atom types should defined before the more general 
   ones
6. For AM1-BCC, five-membered ring connected to a six-membered aromatic ring (like indole) is not
   considered aromatic.
